==> indigitall_flutter_plugin-0.5.0.tar.gz: lib/inapp/models/InAppProperties.dart <==
import 'dart:convert';
import 'dart:io';

import 'InAppAction.dart';

class InAppProperties {
  /// String field name properties
  static const String PROPERTIES = "properties";

  /// String field name action
  static const String _ACTION = InAppAction.ACTION;

  /// String field name content url
  static const String _CONTENT_URL = "contentUrl";

  /// String field name showtime
  static const String _SHOWTIME = "showTime";

  /// String field name number of shows
  static const String _NUMBER_OF_SHOWS = "numberOfShows";

  /// String field name number of clicks
  static const String _NUMBER_OF_CLICKS = "numberOfClicks";

  /// String field name if dismiss forever action
  static const String _DISMISS_FOREVER = "dismissForever";

  /// String field name layout
  static const String _LAYOUT = "layout";

  /// action model of inApp
  InAppAction? action;

  /// content url with the inApp html
  String? contentUrl;

  /// if inApp has show time
  int? showTime;
  //InAppLayout? layout;

  /// number of shows for an inApp
  int? numberOfShows;

  /// number of clicks for a inApp
  int? numberOfClicks;

  /// number of clicks for a inApp
  bool? dismissForever;

  /// Constructor of InAppProperties
  InAppProperties(Map map) {
    map.forEach((key, value) {
      switch (key) {
        case _ACTION:
          if (Platform.isAndroid) {
            action = InAppAction(json.decode(value.toString()));
          } else {
            action = InAppAction(value);
          }
          break;
        case _NUMBER_OF_SHOWS:
          numberOfShows = int.parse(value.toString());
          break;
        case _NUMBER_OF_CLICKS:
          numberOfClicks = int.parse(value.toString());
          break;
        case _DISMISS_FOREVER:
          dismissForever = value.toString().toLowerCase() == 'true';
          break;
        case _CONTENT_URL:
          contentUrl = value.toString();
          break;
        case _SHOWTIME:
          showTime = int.parse(value.toString());
          break;
      }
    });
  }

  /// Conversion to Map
  Map toMap() {
    Map map = Map();
    if (action != null) map[_ACTION] = action!.toMap();
    if (contentUrl != null) map[_CONTENT_URL] = contentUrl;
    if (showTime != null) map[_SHOWTIME] = showTime;
    if (numberOfShows != null) map[_NUMBER_OF_SHOWS] = numberOfShows;
    if (numberOfClicks != null) map[_NUMBER_OF_CLICKS] = numberOfClicks;
    if (dismissForever != null) map[_DISMISS_FOREVER] = dismissForever;
    return map;
  }
}

==> indigitall_flutter_plugin-2.0.2.tar.gz: lib/inapp/models/InAppProperties.dart <==
import 'dart:convert';
import 'dart:io';

import 'InAppAction.dart';

class InAppProperties {
  /// String field name properties
  static const String PROPERTIES = "properties";

  /// String field name action
  static const String _ACTION = InAppAction.ACTION;

  /// String field name content url
  static const String _CONTENT_URL = "contentUrl";

  /// String field name showtime
  static const String _SHOWTIME = "showTime";

  /// String field name number of shows
  static const String _NUMBER_OF_SHOWS = "numberOfShows";

  /// String field name number of clicks
  static const String _NUMBER_OF_CLICKS = "numberOfClicks";

  /// String field name if dismiss forever action
  static const String _DISMISS_FOREVER = "dismissForever";

  // /// String field name layout
  // static const String _LAYOUT = "layout";

  /// action model of inApp
  InAppAction? action;

  /// content url with the inApp html
  String? contentUrl;

  /// if inApp has show time
  int? showTime;
  //InAppLayout? layout;

  /// number of shows for an inApp
  int? numberOfShows;

  /// number of clicks for a inApp
  int? numberOfClicks;

  /// number of clicks for a inApp
  bool? dismissForever;

  /// Constructor of InAppProperties
  InAppProperties(Map map) {
    map.forEach((key, value) {
      switch (key) {
        case _ACTION:
          if (Platform.isAndroid) {
            action = InAppAction(json.decode(value.toString()));
          } else {
            action = InAppAction(value);
          }
          break;
        case _NUMBER_OF_SHOWS:
          numberOfShows = int.parse(value.toString());
          break;
        case _NUMBER_OF_CLICKS:
          numberOfClicks = int.parse(value.toString());
          break;
        case _DISMISS_FOREVER:
          dismissForever = value.toString().toLowerCase() == 'true';
          break;
        case _CONTENT_URL:
          contentUrl = value.toString();
          break;
        case _SHOWTIME:
          showTime = int.parse(value.toString());
          break;
      }
    });
  }

  /// Conversion to Map
  Map toMap() {
    Map map = Map();
    if (action != null) map[_ACTION] = action!.toMap();
    if (contentUrl != null) map[_CONTENT_URL] = contentUrl;
    if (showTime != null) map[_SHOWTIME] = showTime;
    if (numberOfShows != null) map[_NUMBER_OF_SHOWS] = numberOfShows;
    if (numberOfClicks != null) map[_NUMBER_OF_CLICKS] = numberOfClicks;
    if (dismissForever != null) map[_DISMISS_FOREVER] = dismissForever;
    return map;
  }
}
